Documentation
¶
Index ¶
- func AllowAxisFlip(value bool)
- func BeginFrame()
- func DecomposeMatrixToComponents(matrix, translation, rotation, scale *float32)
- func DrawCubes(view, projection, matrices *float32, matrixCount int32)
- func DrawGrid(view, projection, matrix *float32, gridSize float32)
- func Enable(enable bool)
- func GetIDPtr(ptr_id uintptr) imgui.ID
- func GetIDStr(str_id string) imgui.ID
- func GetIDStrStr(str_id_begin, str_id_end string) imgui.ID
- func IsOver() bool
- func IsOverFloatPtr(position *float32, pixelRadius float32) bool
- func IsOverOPERATION(op OPERATION) bool
- func IsUsing() bool
- func IsUsingAny() bool
- func IsUsingViewManipulate() bool
- func IsViewManipulateHovered() bool
- func Manipulate(view, projection *float32, operation OPERATION, mode MODE, matrix *float32) bool
- func ManipulateV(view, projection *float32, operation OPERATION, mode MODE, ...) bool
- func PopID()
- func PushIDInt(int_id int32)
- func PushIDPtr(ptr_id uintptr)
- func PushIDStr(str_id string)
- func PushIDStrStr(str_id_begin, str_id_end string)
- func RecomposeMatrixFromComponents(translation, rotation, scale, matrix *float32)
- func SetAlternativeWindow(window *imgui.Window)
- func SetAxisLimit(value float32)
- func SetAxisMask(x, y, z bool)
- func SetDrawlist()
- func SetDrawlistV(drawlist *imgui.DrawList)
- func SetGizmoSizeClipSpace(value float32)
- func SetID(id int32)
- func SetImGuiContext(ctx *imgui.Context)
- func SetOrthographic(isOrthographic bool)
- func SetPlaneLimit(value float32)
- func SetRect(x, y, width, height float32)
- func ViewManipulateFloat(view *float32, length float32, position, size imgui.Vec2, ...)
- func ViewManipulateFloatPtr(view, projection *float32, operation OPERATION, mode MODE, matrix *float32, ...)
- type COLOR
- type MODE
- type OPERATION
- type Style
- func (self Style) C() (C.Style, func())
- func (self *Style) CenterCircleSize() float32
- func (self *Style) Colors() [15]imgui.Vec4
- func (self *Style) Destroy()
- func (self *Style) Handle() (result *C.Style, fin func())
- func (self *Style) HatchedAxisLineThickness() float32
- func (self *Style) RotationLineThickness() float32
- func (self *Style) RotationOuterLineThickness() float32
- func (self *Style) ScaleLineCircleSize() float32
- func (self *Style) ScaleLineThickness() float32
- func (self Style) SetCenterCircleSize(v float32)
- func (self Style) SetColors(v *[15]imgui.Vec4)
- func (self Style) SetHatchedAxisLineThickness(v float32)
- func (self Style) SetRotationLineThickness(v float32)
- func (self Style) SetRotationOuterLineThickness(v float32)
- func (self Style) SetScaleLineCircleSize(v float32)
- func (self Style) SetScaleLineThickness(v float32)
- func (self Style) SetTranslationLineArrowSize(v float32)
- func (self Style) SetTranslationLineThickness(v float32)
- func (self *Style) TranslationLineArrowSize() float32
- func (self *Style) TranslationLineThickness() float32
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllowAxisFlip ¶
func AllowAxisFlip(value bool)
func BeginFrame ¶
func BeginFrame()
func DecomposeMatrixToComponents ¶
func DecomposeMatrixToComponents(matrix, translation, rotation, scale *float32)
func GetIDStr ¶
calculate unique ID (hash of whole ID stack + given parameter). e.g. if you want to query into ImGuiStorage yourself
func GetIDStrStr ¶
func IsOverFloatPtr ¶
func IsOverOPERATION ¶
func IsUsingAny ¶
func IsUsingAny() bool
func IsUsingViewManipulate ¶
func IsUsingViewManipulate() bool
func IsViewManipulateHovered ¶ added in v1.2.0
func IsViewManipulateHovered() bool
func Manipulate ¶
func ManipulateV ¶
func ManipulateV(view, projection *float32, operation OPERATION, mode MODE, matrix, deltaMatrix, snap, localBounds, boundsSnap *float32) bool
ManipulateV parameter default value hint: deltaMatrix: NULL snap: NULL localBounds: NULL boundsSnap: NULL
func PushIDStrStr ¶
func PushIDStrStr(str_id_begin, str_id_end string)
push string into the ID stack (will hash string).
func RecomposeMatrixFromComponents ¶
func RecomposeMatrixFromComponents(translation, rotation, scale, matrix *float32)
func SetAlternativeWindow ¶
func SetAxisLimit ¶
func SetAxisLimit(value float32)
func SetAxisMask ¶
func SetAxisMask(x, y, z bool)
func SetDrawlist ¶
func SetDrawlist()
func SetDrawlistV ¶
SetDrawlistV parameter default value hint: drawlist: nullptr
func SetGizmoSizeClipSpace ¶
func SetGizmoSizeClipSpace(value float32)
func SetImGuiContext ¶
func SetOrthographic ¶
func SetOrthographic(isOrthographic bool)
func SetPlaneLimit ¶
func SetPlaneLimit(value float32)
func ViewManipulateFloat ¶
Types ¶
type COLOR ¶
type COLOR int32
original name: COLOR
const ( // directionColor[0] DIRECTIONX COLOR = 0 // directionColor[1] DIRECTIONY COLOR = 1 // directionColor[2] DIRECTIONZ COLOR = 2 // planeColor[0] PLANEX COLOR = 3 // planeColor[1] PLANEY COLOR = 4 // planeColor[2] PLANEZ COLOR = 5 // selectionColor SELECTION COLOR = 6 // inactiveColor INACTIVE COLOR = 7 // translationLineColor TRANSLATIONLINE COLOR = 8 SCALELINE COLOR = 9 ROTATIONUSINGBORDER COLOR = 10 ROTATIONUSINGFILL COLOR = 11 HATCHEDAXISLINES COLOR = 12 TEXT COLOR = 13 TEXTSHADOW COLOR = 14 COUNT COLOR = 15 )
type OPERATION ¶
type OPERATION int32
call it when you want a gizmo Needs view and projection matrices. matrix parameter is the source matrix (where will be gizmo be drawn) and might be transformed by the function. Return deltaMatrix is optional translation is applied in world space original name: OPERATION
const ( TRANSLATEX OPERATION = 1 TRANSLATEY OPERATION = 2 TRANSLATEZ OPERATION = 4 ROTATEX OPERATION = 8 ROTATEY OPERATION = 16 ROTATEZ OPERATION = 32 ROTATESCREEN OPERATION = 64 SCALEX OPERATION = 128 SCALEY OPERATION = 256 SCALEZ OPERATION = 512 BOUNDS OPERATION = 1024 SCALEXU OPERATION = 2048 SCALEYU OPERATION = 4096 SCALEZU OPERATION = 8192 TRANSLATE OPERATION = 7 ROTATE OPERATION = 120 SCALE OPERATION = 896 // universal SCALEU OPERATION = 14336 UNIVERSAL OPERATION = 14463 )
type Style ¶
func NewEmptyStyle ¶ added in v1.2.0
func NewEmptyStyle() *Style
NewEmptyStyle creates Style with its 0 value.
func NewStyleFromC ¶
NewStyleFromC creates Style from its C pointer. SRC ~= *C.Style